You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2023/12/05 20:35:33 UTC

(camel) branch main updated: Lets use Camel JBang instead of Camel CLI in the camel log

This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/camel.git


The following commit(s) were added to refs/heads/main by this push:
     new 73d4d7ca039 Lets use Camel JBang instead of Camel CLI in the camel log
73d4d7ca039 is described below

commit 73d4d7ca03912bf7956ca3f328a4984fad46cbf4
Author: Claus Ibsen <cl...@gmail.com>
AuthorDate: Tue Dec 5 21:35:20 2023 +0100

    Lets use Camel JBang instead of Camel CLI in the camel log
---
 .../org/apache/camel/cli/connector/LocalCliConnector.java    | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/dsl/camel-cli-connector/src/main/java/org/apache/camel/cli/connector/LocalCliConnector.java b/dsl/camel-cli-connector/src/main/java/org/apache/camel/cli/connector/LocalCliConnector.java
index 7e886c7cd2c..bc7b89a9ddb 100644
--- a/dsl/camel-cli-connector/src/main/java/org/apache/camel/cli/connector/LocalCliConnector.java
+++ b/dsl/camel-cli-connector/src/main/java/org/apache/camel/cli/connector/LocalCliConnector.java
@@ -89,7 +89,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
  * CLI Connector for local management of Camel integrations from the Camel CLI.
  */
 public class LocalCliConnector extends ServiceSupport implements CliConnector, CamelContextAware {
 
@@ -178,9 +178,9 @@ public class LocalCliConnector extends ServiceSupport implements CliConnector, C
             traceFile = createLockFile(lockFile.getName() + "-trace.json");
             debugFile = createLockFile(lockFile.getName() + "-debug.json");
             executor.scheduleWithFixedDelay(this::task, 0, delay, TimeUnit.MILLISECONDS);
-            LOG.info("Camel CLI enabled (local)");
+            LOG.info("Management from Camel JBang enabled");
         } else {
-            LOG.warn("Cannot create PID file: {}. This integration cannot be managed by Camel CLI.", getPid());
+            LOG.warn("Cannot create PID file: {}. This integration cannot be managed by Camel JBang.", getPid());
         }
     }
 
@@ -197,7 +197,7 @@ public class LocalCliConnector extends ServiceSupport implements CliConnector, C
         terminateExecutor.submit(new Runnable() {
             @Override
             public void run() {
-                LOG.info("Camel CLI terminating JVM");
+                LOG.info("Camel JBang terminating JVM");
                 try {
                     camelContext.stop();
                 } finally {
@@ -718,11 +718,11 @@ public class LocalCliConnector extends ServiceSupport implements CliConnector, C
     private void doActionReloadTask() {
         ContextReloadStrategy cr = camelContext.hasService(ContextReloadStrategy.class);
         if (cr != null) {
-            cr.onReload("Camel CLI");
+            cr.onReload("Camel JBang");
         } else {
             ResourceReloadStrategy rr = camelContext.hasService(ResourceReloadStrategy.class);
             if (rr != null) {
-                rr.onReload("Camel CLI");
+                rr.onReload("Camel JBang");
             }
         }
     }
@@ -89,7 +89,7 @@ import org.slf4j.Logger;
 
 /**
- * CLI Connector for local management of Camel integrations from the Camel CLI.
+ * CLI Connector for local management of Camel integrations from Camel JBang.
  */
 public class LocalCliConnector extends ServiceSupport implements CliConnector, CamelContextAware {